@@ -39,7 +39,7 @@
 #include <linux/uaccess.h>
 #include <asm/irq.h>
 
-#include "fbcon.h"
+#include "../fbdev/core/fbcon.h"
 #include "fbcondecor.h"
 
 extern signed char con2fb_map[];
